## Estructura de contención jerárquica

El esquema lógico de OpenGnsys proporciona los elementos para organizar los equipos informáticos en una estructura de contención jerárquica simplificada, así como el control de usuarios que tendrán acceso al esquema o a parte de éste.

La nueva estructura jerárquica se ha simplificado significativamente, basándose ahora en dos elementos principales: **Unidades Organizativas (Grupos)** y **Clientes (Estaciones de Trabajo)**.

- **Unidades Organizativas (Grupos):**
Los grupos pueden ser del tipo que se desee según las necesidades organizacionales, permitiendo una estructura completamente flexible y adaptable a cualquier contexto organizacional.

- **Clientes (Estaciones de Trabajo):**
Representan los equipos individuales que serán gestionados por OpenGnsys.

Esta estructura simplificada permite una mayor flexibilidad organizacional, pudiendo adaptarse conceptualmente a cualquier tipo de situación. Por ejemplo, estaciones de trabajo aisladas en diferentes localizaciones geográficas pueden agruparse eficientemente en un "grupo de clientes" específico, facilitando su gestión centralizada.

Uno de los elementos principales para la organización sigue siendo la **unidad organizativa**. Su principal función es agrupar objetos con fines administrativos y permitir la delegación de autoridad.

La delegación permite distribuir la administración de un gran número de centros, departamentos o laboratorios, entre una serie de usuarios de tipo administrador en quienes se confía para realizar tareas de administración específicas.

### Concepto de ámbito de aplicación

Cada elemento jerárquico establece un **ámbito de aplicación**, concepto fundamental en el diseño de la infraestructura. Este ámbito determina sobre qué conjunto de equipos se pueden ejecutar tareas específicas, proporcionando un control granular y organizado de las operaciones de gestión.

!!! tip "Diseño de infraestructura"
    El ámbito de aplicación es clave para planificar eficientemente la gestión de equipos en tu organización.

### Administración descentralizada

La herramienta de administración de OpenGnsys permite que un único administrador gestione los recursos de forma centralizada. Además de esta administración centralizada, se puede definir una administración descentralizada que aprovecha la nueva estructura jerárquica simplificada.

#### Delegación de autoridad sobre una unidad organizativa

El administrador de la consola o superadministrador puede gestionar la delegación de responsabilidades administrativas para unidades organizativas específicas en otros administradores.

Con la nueva estructura simplificada, esta delegación puede realizarse sobre cualquier tipo de grupo, proporcionando mayor flexibilidad en la distribución de responsabilidades administrativas.

Estos administradores gestionarán su unidad organizativa mediante la interfaz web de la consola, teniendo control total sobre los elementos contenidos en su ámbito de responsabilidad.

#### Delegación de tareas a usuarios con o sin autoridad

El administrador de una unidad organizativa puede delegar tareas específicas sobre los ámbitos que pertenecen a su unidad organizativa, independientemente del tipo de grupo que administre.

Estas tareas delegadas son accesibles por el usuario desde el propio terminal del ordenador gestionado. Las tareas delegadas se incluyen en un menú que puede requerir autenticación –menú privado– o no –menú público–.

Un **menú público** normalmente incluye la tarea de iniciar un determinado sistema operativo. En cambio, un **menú privado** –que requiere autenticación– está destinado a ofrecer opciones de clonación sobre el propio ordenador o sobre todos los ordenadores de un grupo específico.

La flexibilidad de la nueva estructura permite que estas delegaciones se adapten a diferentes escenarios organizacionales, desde estructuras tradicionales hasta grupos distribuidos geográficamente.

### El esquema predefinido de OpenGnsys

Durante el proceso de instalación de OpenGnsys se configura de manera automática el esquema, ofreciendo una estructura básica adaptada a la nueva jerarquía simplificada. Esta configuración predeterminada implementa los cuatro tipos conceptuales de Unidades Organizativas para facilitar la gestión organizacional.

#### Estructura predeterminada

El esquema predefinido establece la siguiente jerarquía organizacional:

- **Centro**: Representa el nivel organizacional principal
- **Grupo de Aulas**: Permite agrupar múltiples aulas con características similares
- **Aula**: Define espacios físicos específicos con equipos informáticos
- **Grupo de Clientes**: Facilita la agrupación de estaciones de trabajo específicas

Esta estructura predeterminada puede adaptarse completamente a las necesidades específicas de cada organización, permitiendo crear grupos anidables a múltiples niveles según los requerimientos particulares.

#### Configuración administrativa inicial

El acceso a la administración de la consola está permitido inicialmente a un solo usuario de tipo superadministrador, que además tiene los derechos de administración sobre todas las unidades organizativas por defecto. El nombre de este usuario y su contraseña son los indicados durante el proceso de instalación.

La administración de las unidades organizativas delegadas está inicialmente sin definir, a excepción del servicio repositorio de imágenes OpenGnsys, que por defecto es el equipo donde se ha instalado la aplicación.

#### Flexibilidad organizacional

Aunque se proporciona esta estructura predeterminada basada en el modelo educativo tradicional (Centro→Grupo de Aulas→Aula→Grupo de Clientes), la nueva arquitectura permite trascender este esquema, facilitando organizaciones más complejas o diferentes según las necesidades específicas de cada entorno.

Esta flexibilidad permite que estaciones de trabajo aisladas en diferentes localizaciones se puedan agrupar eficientemente, o que se implementen estructuras organizacionales completamente diferentes al modelo educativo tradicional.

### Administración de los Grupos

Para administrar los grupos, accedemos al módulo **Grupos** del menú lateral izquierdo, donde se nos presentará la siguiente pantalla

- Menú de Filtros y Búsqueda
- Arbol de Grupos (Unidad Organizativa/Aula)
- Clientes (correspondientes al grupo seleccionado en el panel de la izquierda)

![oggui-grupos.png](../../assets/images/screenshots/oggui-grupos.png){ style="display: block; margin: 20px auto; max-width: min(1024px, 100%); height: auto;" }

### Características de los Grupos

Los grupos permiten la herencia de configuración, lo que significa que los ajustes aplicados a un grupo superior se heredan automáticamente en los grupos inferiores, si no se indica lo contrario. Esto incluye:

- Red y servicio DHCP
- Configuración del Boot Server
  - Versión de ogLive
  - Plantilla PXE
- Servidor NTP
- Repositorio de imágenes
  - Configuración P2P (modo, tiempo)
  - Configuración Multicast (velocidad, puerto, modo)
- Menú de arranque
- Perfil de hardware

#### Creación de Grupos

Para crear un nuevo grupo:

1. Accede al menú de **Grupos**
2. Selecciona "Nueva Unidad Organizativa"
3. Define el tipo de grupo (Centro, Grupo de Aulas, Aula, Grupo de ClientesCentro, Grupo de Aulas, Aula, Grupo de Clientes)
4. Completa la información requerida
5. Guarda los cambios

![oggui-grupos_crear.png](../../assets/images/screenshots/oggui-grupos_crear.png){ style="display: block; margin: 20px auto; max-width: min(1024px, 100%); height: auto;" }

#### Creación de Clientes

Para dar de alta clientes existen dos opciones

- Alta de un cliente individual
- Alta masiva de clientes

Para dar de alta un cliente:

1. Accede al menú **Grupos**
2. Nuevo Cliente -> Añadir cliente unitario
3. Cubrir la información del cliente

![oggui-grupos_crear-cliente.png](../../assets/images/screenshots/oggui-grupos_crear-cliente.png){ style="display: block; margin: 20px auto; max-width: min(1024px, 100%); height: auto;" }

Para dar de alta varios clientes de forma masiva

- Se debe elaborar un fichero de texto (puede ser `.txt` o cualquier formato de texto plano) que tenga la siguiente estructura de configuración DHCP:

```
host nombre_host01 {
    hardware ethernet a0:48:1c:8a:f1:5c;
    fixed-address 172.17.69.11;
}
host nombre_host02 {
    hardware ethernet a0:48:1c:8a:f1:5d;
    fixed-address 172.17.69.12;
}
```

- Se elige a qué **Grupo** van a pertenecer los clientes
- Existen dos opciones para cargar los datos:
    - **Subir fichero**: Se carga el fichero con el formato correspondiente
    - **Pegar contenido**: Se pega directamente el contenido en la ventana de importación

![oggui-grupos_crear-clienteS.png](../../assets/images/screenshots/oggui-grupos_crear-clienteS.png){ style="display: block; margin: 20px auto; max-width: min(1024px, 100%); height: auto;" }
